@@ -2,9 +2,10 @@
 
 https://github.com/tidyverse/dplyr/blob/master/R/rename.R
 """
-from pandas import DataFrame
 from pipda import register_verb
 
+from ..core.backends.pandas import DataFrame
+
 from ..core.contexts import Context
 from ..core.utils import vars_select, regcall
 from ..core.tibble import TibbleGrouped
