@@ -5,7 +5,7 @@ https://github.com/tidyverse/tidyr/blob/HEAD/R/complete.R
 
 from typing import Iterable, Mapping, Any
 
-from pandas import DataFrame
+from ..core.backends.pandas import DataFrame
 from pipda import register_verb
 
 from ..core.contexts import Context
