@@ -2,9 +2,9 @@
 
 from typing import List, Any, Union, Callable, Mapping
 
-import pandas as pd
-from pandas import DataFrame, Index
-from pandas.api.types import is_scalar
+from ..core.backends import pandas as pd
+from ..core.backends.pandas import DataFrame, Index
+from ..core.backends.pandas.api.types import is_scalar
 from pipda import register_verb
 
 from ..core.contexts import Context
@@ -129,6 +129,8 @@ def pivot_wider(
 
     # hold NAs in values_from columns, so that they won't be filled
     # by values_fill
+    if values_from and ret is _data:
+        ret = _data.copy()
     for col in values_from:
         ret[col].fillna(NA_integer_, inplace=True)
 
